<?

 /*************************************************************************************
 * Filename: modules/pluginConfigs.php
 *
 * This file is part of the Forum JAS plugin.
 * Copyright 2003-2015 by Matthijs Schuurman
 *
 * The Forum JAS plugin is free software under the terms of the
 * GNU General Public License version 3 or any later version.
 *
 * For information about the license please refer to:
 * LICENSE.txt in the root of the plugin or http://jas.junerules.com/plugins/forum/
 *************************************************************************************/


 require_once($_path["include"]."module.php");

 class Plugin_Module_forum_pluginConfigs extends Module
 {
  function __construct(&$data)
  {
   parent::__construct($data);

   if($this->data->module!="pluginConfigs")
    $this->extend("pluginConfigs");

   $this->data->title="Forum plugin configuration";

   $this->data->addField("listtype", "enum", "all", "reload", false, false, "Latest blogs", "Show");
   $this->data->enumOptions("listtype", "Latest blogs", "Blog entry", "Tag cloud");

   $this->data->addField("static", "boolean", "all", "reload", false, false, false, "List specific category");
   $this->data->addField("listcatnr", "nr", "all", "", false, false, 0, "List category");
   $this->data->addReference("listcatnr", "categories", "nr", "*:0");

   $this->data->addField("itempage", "boolean", "all", "reload", false, false, false, "Use item page");
   $this->data->addField("itempagenr", "nr", "all", "", false, false, false, "Item page");
   $this->data->addReference("itempagenr", "categories", "nr", "*:0");

   $this->data->addField("cmspage", "boolean", "all", "reload", false, false, false, "Use CMS page");
   $this->data->addField("cmspagenr", "nr", "all", "", false, false, false, "CMS page");
   $this->data->addReference("cmspagenr", "categories", "nr", "*:0");

   $this->data->addField("pagebrowser", "boolean", "all", "reload", false, false, true, "Show page browser");
   $this->data->addField("listitems", "nr", "all", "", 0, 100, 10, "Number of blog entries");
   $this->data->addField("templatepagebrowser", "localfile", "all", "recursive", false, 255, "", "Alternative page browser template");

   $this->data->addField("templateitem", "localfile", "all", "recursive", false, 255, "", "Item template");
   $this->data->addField("templatelist", "localfile", "all", "recursive", false, 255, "", "List template");
   $this->data->addField("templatecategories", "localfile", "all", "recursive", false, 255, "", "Categories template");
   $this->data->addField("templatetree", "localfile", "all", "recursive", false, 255, "", "Tree template");

   $this->data->group("Show", "listtype", "static", "listcatnr", "itempage", "itempagenr", "cmspage", "cmspagenr");
   $this->data->group("Page browser", "pagebrowser", "listitems", "templatepagebrowser");
   $this->data->group("Alternative templates", "templateitem", "templatelist", "templatecategories", "templatetree");
  }

  function postInit()
  {
   global $_path;

   $this->data->setFileDir("templatepagebrowser", $_path["project"]["templates"]);
   $this->data->setFileExtensions("templatepagebrowser", "html", "htm");
   $this->data->setFileDir("templateitem", $_path["project"]["templates"]);
   $this->data->setFileExtensions("templateitem", "html", "htm");
   $this->data->setFileDir("templatelist", $_path["project"]["templates"]);
   $this->data->setFileExtensions("templatelist", "html", "htm");
   $this->data->setFileDir("templatecategories", $_path["project"]["templates"]);
   $this->data->setFileExtensions("templatecategories", "html", "htm");
   $this->data->setFileDir("templatetree", $_path["project"]["templates"]);
   $this->data->setFileExtensions("templatetree", "html", "htm");

   return $this->customizeFields();
  }
  function copyPostGet(){return $this->customizeFields();}
  function editPostGet(){return $this->customizeFields();}
  function movePostGet(){return $this->customizeFields();}
  function deletePostGet(){return $this->customizeFields();}

  function customizeFields()
  {
   if($this->data->getValue("listtype")=="Latest blogs")
   {
    $this->data->resetField("static");

    if($this->data->getValue("static"))
     $this->data->resetField("listcatnr");
    else
     $this->data->field["listcatnr"]["properties"].=";hidden";


    $this->data->resetField("itempage");

    if($this->data->getValue("itempage"))
     $this->data->resetField("itempagenr");
    else
     $this->data->field["itempagenr"]["properties"].=";hidden";


    $this->data->resetField("cmspage");

    if($this->data->getValue("cmspage"))
     $this->data->resetField("cmspagenr");
    else
     $this->data->field["cmspagenr"]["properties"].=";hidden";


    $this->data->resetField("listitems");


    $this->data->resetField("pagebrowser");

    if(!$this->data->getValue("pagebrowser"))
    {
     $this->data->field["templatepagebrowser"]["properties"].=";hidden";

     //move listitems to List group
     $this->data->field["listitems"]["min"]=0;
     $this->data->field["listitems"]["defaultvalue"]=0;
     $this->data->field["listitems"]["group"]=$this->data->getGroupID("Show");

     $this->data->field["listitems"]["title"]="Number of blog entries";
    }
    else
    {
     $this->data->resetField("templatepagebrowser");

     $this->data->resetField("listitems");
     $this->data->field["listitems"]["group"]=$this->data->getGroupID("Page browser");
     $this->data->field["listitems"]["title"]="Items per page";
    }

    $this->data->resetField("templateitem");
    $this->data->resetField("templatelist");

   }
   else if($this->data->getValue("listtype")=="Blog entry")
   {
    $this->data->field["static"]["properties"].=";hidden";
    $this->data->field["listcatnr"]["properties"].=";hidden";

    $this->data->field["itempage"]["properties"].=";hidden";
    $this->data->field["itempagenr"]["properties"].=";hidden";

    $this->data->field["cmspage"]["properties"].=";hidden";
    $this->data->field["cmspagenr"]["properties"].=";hidden";

    $this->data->field["pagebrowser"]["properties"].=";hidden";
    $this->data->field["templatepagebrowser"]["properties"].=";hidden";
    $this->data->field["listitems"]["properties"].=";hidden";

    $this->data->resetField("templateitem");
    $this->data->field["templatelist"]["properties"].=";hidden";
   }
   else //tags cloud
   {
    $this->data->field["static"]["properties"].=";hidden";
    $this->data->field["listcatnr"]["properties"].=";hidden";

    $this->data->field["itempage"]["properties"].=";hidden";
    $this->data->field["itempagenr"]["properties"].=";hidden";

    $this->data->field["cmspage"]["properties"].=";hidden";
    $this->data->field["cmspagenr"]["properties"].=";hidden";

    $this->data->field["pagebrowser"]["properties"].=";hidden";
    $this->data->field["templatepagebrowser"]["properties"].=";hidden";
    $this->data->field["listitems"]["properties"].=";hidden";

    $this->data->field["templateitem"]["properties"].=";hidden";
    $this->data->field["templatelist"]["properties"].=";hidden";
   }

   return true;
  }

 }
?>
