<?

 /*************************************************************************************
 * Filename: modules/threads.php
 *
 * This file is part of the Forum JAS plugin.
 * Copyright 2003-2015 by Matthijs Schuurman
 *
 * The Forum JAS plugin is free software under the terms of the
 * GNU General Public License version 3 or any later version.
 *
 * For information about the license please refer to:
 * LICENSE.txt in the root of the plugin or http://jas.junerules.com/plugins/forum/
 *************************************************************************************/


 require_once($_path["include"]."module.php");

 class Plugin_Module_forum_threads extends Module
 {
  function __construct(&$data)
  {
   parent::__construct($data);

   $this->data->title="Forum thread";
   $this->data->addField("subject", "text", "all", "title", 5, 255, false, "Subject");
   $this->data->addField("message", "html", "all", "wysiwyg", 10, 65536, false, "Message");

   $this->data->addField("threadnr", "nr", "form;show;sql", "", 0, false, 0, "Thread");
   $this->data->addReference("threadnr", "forum_threads", "nr", "*:0");

   $this->data->addField("replies", "nr", "show", false, false, false, 0, "Replies");

   $this->data->addField("lastreply", "nr", "show", false, false, false, false, "Last reply");
   $this->data->addReference("lastreply", "forum_threads", "nr", "*:0");

   $this->data->defaultFields();

   $this->data->group("Thread", "replies", "lastreply");
   $this->data->group("Other", "catnr", "owner", "updated", "added", "treedepth");

   $this->data->sortOrder("updated-");
  }


  function addPostSubmitErrorCheck(){return $this->additionalSubmitCheck();}

  function additionalSubmitCheck()
  {
   if($this->data->getValue("threadnr")) //reply
   {
    //force replies under the same category as the original
    $d=Data::cache($this->data->module, "view", "item");
    $d->setShowFields("catnr");
    $d->clearValues();

    for($c=0;$c<$this->data->vmax;$c++)
    {
     $d->setValue("nr", $this->data->getValue("threadnr", $c));

     if(!$d->get()) 
     {
      $this->data->e->add($d->e);
      return false;
     }

     if(!$d->getValue("catnr"))
     {
      $this->data->e->add("Replied thread doesn't exist", "error");
      return false;
     }

     $this->data->setValue("catnr", $d->getValue("catnr"), $c);
    }
   }
   else //new
   {
    //force thread under valid forum_categories
    $d=Data::cache("forum_categories", "view", "all");
    $d->setShowFields();
    $d->clearValues();

    for($c=0;$c<$this->data->vmax;$c++)
    {
     $d->setValue("nr", $this->data->getValue("catnr", $c));

     if(!$d->get(false, true)) //get count
     {
      $this->data->e->add($d->e);
      return false;
     }

     if(!$d->getValue("show_count"))
     {
      $this->data->e->add("Thread must be place in a valid forum category", "error");
      return false;
     }
    }
   }

   return true;
  }


  function movePostSubmitErrorCheck()
  {
   if(isset($this->data->skipMoveCheck)&&$this->data->skipMoveCheck)
    return true;

   $d=Data::cache($this->data->module, "view", "all");
   $d->setShowFields("nr");

   //check if submitted threads are top levels
   for($c=0;$c<$this->data->vmax;$c++)
   {
    //get thread if it is at top level
    $d->clearValues();
    $d->setValue("nr", $this->data->getValue("nr", $c));
    $d->setValue("threadnr", 0);

    if(!$d->get()) 
    {
     $this->data->e->add($d->e);
     return false;
    }

    if(!$d->next())
    {
     $this->data->e->add("Can't move non top level threads", "error");
     return false;
    }
   }

   return true;
  }

  function movePreSubmit()
  {
   $d=Data::cache($this->data->module, "view", "all");
   $d->setShowFields("nr");

   //set skipMoveCheck for underlying threads
   $d->skipMoveCheck=true;

   //move all underlying threads
   for($c=0;$c<$this->data->vmax;$c++)
   {
    //get underlying threads
    $d->setAction("view");
    $d->setExtra("all");
    $d->clearValues();

    $d->setValue("threadnr", $this->data->getValue("nr", $c));

    if(!$d->get()) 
    {
     $this->data->e->add($d->e);
     return false;
    }

    if($d->vmax)
    {
     //move underlying threads (only 1st level, since these will trigger the levels underneath)
     $d->setAction("move");
     $d->setExtra("item");

     $d->setValue("newcatnr", $this->data->getValue("newcatnr", $c));
     
     if(!$d->submit()) 
     {
      $this->data->e->add($d->e);
      return false;
     }
    }
   }

   return true;
  }


  function deletePreSubmit()
  {
   $d=Data::cache($this->data->module, "view", "all");
   $d->setShowFields("nr");

   //delete all underlying threads
   for($c=0;$c<$this->data->vmax;$c++)
   {
    //get underlying threads
    $d->setAction("view");
    $d->setExtra("all");
    $d->clearValues();

    $d->setValue("threadnr", $this->data->getValue("nr", $c));

    if(!$d->get()) 
    {
     $this->data->e->add($d->e);
     return false;
    }

    if($d->vmax)
    {
     //delete underlying threads (only 1st level, since these will trigger the levels underneath)
     $d->setAction("delete");
     $d->setExtra("item");
     
     if(!$d->submit()) 
     {
      $this->data->e->add($d->e);
      return false;
     }
    }
   }

   return true;
  }


  function movePostGet(){return $this->viewPostGet();}
  function deletePostGet(){return $this->viewPostGet();}

  function viewPostGet()
  {
   //get total reply per thread 
   if($this->data->check("use", "show", "replies"))
   {
    $d=Data::cache($this->data->module, "tree", "down");
    $d->setShowFields();
    $d->clearValues();

    for($c=0;$c<$this->data->vmax;$c++)
    {
     $d->setValue("threadnr", $this->data->getValue("nr", $c));

     if(!$d->get(false, true)) //get count
     {
      $this->data->e->add($d->e);
      return false;
     }

     $this->data->setValue("replies", $d->getValue("show_count"), $c);
    }
   }

   //get last reply
   if($this->data->check("use", "show", "lastreply"))
   {
    $d=Data::cache($this->data->module, "tree", "down");
    $d->setShowFields("nr", "updated"); //also get updated for resort
    $d->clearValues();
    $d->sortOrder("updated-");

    for($c=0;$c<$this->data->vmax;$c++)
    {
     $d->setValue("threadnr", $this->data->getValue("nr", $c)); //get all messages in thread for resort

     if(!$d->get()) 
     {
      $this->data->e->add($d->e);
      return false;
     }

     $d->resort(); //resort data set since db sort only sorts sub trees

     $this->data->setValue("lastreply", $d->getValue("nr"), $c);
    }
   }

   return true;
  }

 }
?>
